@@ -41,7 +41,8 @@ AlterViewDialog::AlterViewDialog(const QString & name, const QString & schema, Q
 	setWindowTitle(tr("Alter View"));
 	ui.createButton->setText("&Alter");
 
-	highlighter = new SqlHighlighter(ui.sqlEdit->document());
+// 	highlighter =
+	new SqlEditorTools::SqlHighlighter(ui.sqlEdit->document());
 
 	connect(ui.createButton, SIGNAL(clicked()), this, SLOT(createButton_clicked()));
 }
