@@ -12,8 +12,6 @@ for which a new license (GPL+exception) is in place.
 
 #include "ui_createtriggerdialog.h"
 
-class SqlHighlighter;
-
 
 /*! \brief GUI for trigger creation
 \author Petr Vanek <petr@scribus.info>
@@ -30,7 +28,6 @@ class CreateTriggerDialog : public QDialog
 
 	private:
 		Ui::CreateTriggerDialog ui;
-		SqlHighlighter * highlighter;
 
 	private slots:
 		void createButton_clicked();
