@@ -11,6 +11,7 @@ for which a new license (GPL+exception) is in place.
 #include <QDialog>
 #include <QTextStream>
 #include <QSqlTableModel>
+#include <QFile>
 
 #include "ui_dataexportdialog.h"
 #include "sqlmodels.h"
@@ -39,6 +40,7 @@ class DataExportDialog : public QDialog
 
 		QTextStream out;
 		QString clipboard;
+		QFile file;
 		bool exportFile;
 
 		Ui::DataExportDialog ui;
@@ -55,6 +57,11 @@ class DataExportDialog : public QDialog
 
 		bool setProgress(int p);
 
+		/*! \brief Export table header strings too?
+		\retval bool true = export, false = do not export header */
+		bool header();
+		QString endl();
+
 	private slots:
 		void fileButton_toggled(bool);
 		void searchButton_clicked();
