@@ -17,15 +17,18 @@ class HelpBrowser : public QMainWindow
 	Q_OBJECT
 
 	public:
-		HelpBrowser(QWidget * parent = 0);
+		HelpBrowser(const QString & lang, QWidget * parent = 0);
 		~HelpBrowser(){};
 
 	private:
 		Ui::HelpBrowser ui;
 		void closeEvent(QCloseEvent *e);
+		void setHistoryButtonsState();
 
 	private slots:
 		void menuBrowser_anchorClicked(const QUrl &);
+		void forward();
+		void backward();
 };
 
 #endif
