@@ -152,6 +152,9 @@ void LiteManWindow::initActions()
 	aboutAct = new QAction(tr("&About..."), this);
 	connect(aboutAct, SIGNAL(triggered()), this, SLOT(about()));
 
+	aboutQtAct = new QAction(tr("About &Qt..."), this);
+	connect(aboutQtAct, SIGNAL(triggered()), this, SLOT(aboutQt()));
+
 	helpAct = new QAction(tr("&Help Content..."), this);
 	helpAct->setShortcut(tr("F1"));
 	connect(helpAct, SIGNAL(triggered()), this, SLOT(help()));
@@ -280,6 +283,7 @@ void LiteManWindow::initMenus()
 	QMenu * helpMenu = menuBar()->addMenu(tr("&Help"));
 	helpMenu->addAction(helpAct);
 	helpMenu->addAction(aboutAct);
+	helpMenu->addAction(aboutQtAct);
 
 	databaseMenu->setEnabled(false);
 	adminMenu->setEnabled(false);
@@ -306,6 +310,7 @@ void LiteManWindow::rebuildRecentFileMenu()
 	recentFilesMenu->clear();
 	uint max = qMin(PreferencesDialog::recentlyUsedCount(), recentDocs.count());
 	QFile fi;
+	QString accel("&");
 
 	for (uint i = 0; i < max; ++i)
 	{
@@ -315,7 +320,10 @@ void LiteManWindow::rebuildRecentFileMenu()
 			removeRecent(recentDocs.at(i));
 			break;
 		}
-		QAction *a = new QAction(QString("&%1 %2").arg(i+1).arg(recentDocs.at(i)), this);
+		// &10 collides with &1
+		if (i > 8)
+			accel = "";
+		QAction *a = new QAction(QString("%1%2 %3").arg(accel).arg(i+1).arg(recentDocs.at(i)), this);
 		a->setData(QVariant(recentDocs.at(i)));
 		connect(a, SIGNAL(triggered()), this, SLOT(openRecent()));
 		recentFilesMenu->addAction(a);
@@ -327,12 +335,9 @@ void LiteManWindow::readSettings()
 {
 	QSettings settings("yarpen.cz", "sqliteman");
 
-	QPoint pos = settings.value("window/pos", QPoint(200, 200)).toPoint();
-	QSize size = settings.value("window/size", QSize(800, 600)).toSize();
+	restoreGeometry(settings.value("window/geometry").toByteArray());
 	QByteArray splitterData = settings.value("window/splitter").toByteArray();
 
-	move(pos);
-	resize(size);
 	splitter->restoreState(splitterData);
 	splitterSql->restoreState(settings.value("sqleditor/splitter").toByteArray());
 	dataViewer->restoreSplitter(settings.value("dataviewer/splitter").toByteArray());
@@ -354,7 +359,7 @@ void LiteManWindow::writeSettings()
 {
 	QSettings settings("yarpen.cz", "sqliteman");
 
-	settings.setValue("window/pos", pos());
+	settings.setValue("window/geometry", saveGeometry());
 	settings.setValue("window/size", size());
 	settings.setValue("window/splitter", splitter->saveState());
 	settings.setValue("objectbrowser/show", tableTree->isVisible());
@@ -415,7 +420,8 @@ void LiteManWindow::openDatabase(const QString & fileName)
 
 	QFileInfo fi(fileName);
 	QDir::setCurrent(fi.absolutePath());
-	m_mainDbPath = fi.absoluteFilePath();
+	m_mainDbPath = QDir::toNativeSeparators(QDir::currentPath() + "/" + fi.fileName());
+
 	updateRecent(fileName);
 
 	// Build tree & clean model
@@ -447,10 +453,15 @@ void LiteManWindow::about()
 						  "(c) 2007 Petr Vanek").arg(SQLITEMAN_VERSION));
 }
 
+void LiteManWindow::aboutQt()
+{
+	QMessageBox::aboutQt(this, m_appName);
+}
+
 void LiteManWindow::help()
 {
 	if (!helpBrowser)
-		helpBrowser = new HelpBrowser(this);
+		helpBrowser = new HelpBrowser(m_lang, this);
 	helpBrowser->show();
 }
 
@@ -470,10 +481,9 @@ void LiteManWindow::handleSqlEditor()
 	sqlEditor->setVisible(!sqlEditor->isVisible());
 	execSqlAct->setChecked(sqlEditor->isVisible());
 }
-#include <QtDebug>
+
 void LiteManWindow::handleObjectBrowser()
 {
-	qDebug() << "1";
 	tableTree->setVisible(!tableTree->isVisible());
 	objectBrowserAct->setChecked(tableTree->isVisible());
 }
@@ -509,7 +519,7 @@ void LiteManWindow::execSql(QString query)
 	else
 	{
 		dataViewer->setStatusText(tr("Query OK\nRow(s) returned: %1\n\n%2").arg(model->rowCount()).arg(query));
-		if (SqlParser::updateTree(query))
+		if (SqlEditorTools::SqlParser::updateTree(query))
 			tableTree->buildTree();
 	}
 }
