@@ -38,6 +38,9 @@ class LiteManWindow : public QMainWindow
 	public:
 		LiteManWindow(const QString & fileToOpen = 0);
 		~LiteManWindow(){};
+
+		//! \brief Set the chosen language (used in the translator) to localize help too.
+		void setLanguage(QString l) { m_lang = l; };
 	
 	private:
 		void initUI();
@@ -86,6 +89,7 @@ class LiteManWindow : public QMainWindow
 		void open(const QString & file = QString());
 		void openRecent();
 		void about();
+		void aboutQt();
 		void help();
 		void preferences();
 
@@ -134,7 +138,9 @@ class LiteManWindow : public QMainWindow
 
 		QString m_mainDbPath;
 		QString m_appName;
-		/*! alias name - connection name mappings
+		QString m_lang;
+
+		/*! \brief alias name - connection name mappings
 		It's used for mapping of the attached databases for QSqlTableModel
 		as it does not support database.table naming schema */
 		QMap<QString,QString> attachedDb;
@@ -156,6 +162,7 @@ class LiteManWindow : public QMainWindow
 		QAction * recentAct;
 		QAction * exitAct;
 		QAction * aboutAct;
+		QAction * aboutQtAct;
 		QAction * helpAct;
 		QAction * preferencesAct;
 		
