@@ -5,9 +5,14 @@ a copyright and/or license notice that predates the release of Sqliteman
 for which a new license (GPL+exception) is in place.
 */
 
-#include <iostream>
+// #include <iostream>
 #include <signal.h>
 
+// required for *BSD
+#ifndef HAVE_WIN
+#include <unistd.h>
+#endif
+
 #include <QApplication>
 #include <QIcon>
 #include <QDir>
@@ -15,6 +20,7 @@ for which a new license (GPL+exception) is in place.
 #include <QTranslator>
 #include <QStyleFactory>
 #include <QMessageBox>
+#include <QTextStream>
 
 #include "litemanwindow.h"
 #include "preferencesdialog.h"
@@ -27,6 +33,7 @@ for which a new license (GPL+exception) is in place.
 #define ARG_HELP_SHORT "-h"
 #define ARG_LANG_SHORT "-l"
 #define ARG_AVAILLANG_SHORT "-la"
+#define endl QString("\n")
 
 
 #ifndef HAVE_WIN
@@ -46,6 +53,7 @@ class ArgsParser
 		~ArgsParser(){};
 		bool parseArgs();
 		QString translator();
+		QString localeCode();
 		const QString & fileToOpen() { return m_file; };
 	private:
 		int argc;
@@ -73,17 +81,21 @@ ArgsParser::ArgsParser(int c, char ** v) :	argc(c), argv(v), m_locale(""), m_fil
 //! \brief Print available translations
 void ArgsParser::langsAvailable()
 {
-	std::cout << "Available translation:" << std::endl;
+	// HACK: QTextStream simulates std::cout here. It can handle
+	// QStrings without any issues. E.g. std::cout << QString::toStdString()
+	// does compile problems in some Qt4 configurations.
+	QTextStream cout(stdout, QIODevice::WriteOnly);
+	cout << QString("Available translation:") << endl;
 	foreach (QString l, m_localeList.values())
-		std::cout << "  --lang " << l.toStdString() << std::endl;
+		cout << QString("  --lang ") << l << endl;
 }
 
 /*! \brief Get the right translations.
-Priprity: 1) specified from CLI - it overrides Prefs or System
+Property: 1) specified from CLI - it overrides Prefs or System
 2) from preferences
 3) system pre-configured
 */
-QString ArgsParser::translator()
+QString ArgsParser::localeCode()
 {
 	QString ret;
 	if (!m_locale.isEmpty())
@@ -92,12 +104,19 @@ QString ArgsParser::translator()
 		ret = m_localeList[PreferencesDialog::GUItranslator()];
 	else
 		ret = QLocale::system().name();
-	return QDir::toNativeSeparators(QString("%1/sqliteman_%2.qm").arg(TRANSLATION_DIR).arg(ret.left(2)));
+	return ret.left(2);
+}
+
+//! \brief Full qualified localisation file path.
+QString ArgsParser::translator()
+{
+	return QDir::toNativeSeparators(QString("%1/sqliteman_%2.qm").arg(TRANSLATION_DIR).arg(localeCode()));
 }
 
 bool ArgsParser::parseArgs()
 {
 	QString arg("");
+	QTextStream cout(stdout, QIODevice::WriteOnly);
 
 	for(int i = 1; i < argc; i++)
 	{
@@ -110,18 +129,18 @@ bool ArgsParser::parseArgs()
 		}
 		else if (arg == ARG_VERSION || arg == ARG_VERSION_SHORT)
 		{
-			std::cout << "Sqliteman " << SQLITEMAN_VERSION << std::endl;
+			cout << QString("Sqliteman ") << SQLITEMAN_VERSION << endl;
 			return false;
 		}
 		else if (arg == ARG_HELP || arg == ARG_HELP_SHORT)
 		{
-			std::cout << std::endl << "sqliteman [options] [databasefile]" << std::endl;
-			std::cout << "options:" << std::endl;
-			std::cout << "  --help    -h  displays small help" << std::endl;
-			std::cout << "  --version -v  prints version" << std::endl;
-			std::cout << "  --lang    -l  set a GUI language. E.g. --lang cs for Czech" << std::endl;
-			std::cout << "  --langs   -la lists available languages" << std::endl;
-			std::cout << "  + various Qt options" << std::endl << std::endl;
+			cout << endl << QString("sqliteman [options] [databasefile]") << endl;
+			cout << QString("options:") << endl;
+			cout << QString("  --help    -h  displays small help") << endl;
+			cout << QString("  --version -v  prints version") << endl;
+			cout << QString("  --lang    -l  set a GUI language. E.g. --lang cs for Czech") << endl;
+			cout << QString("  --langs   -la lists available languages") << endl;
+			cout << QString("  + various Qt options") << endl << endl;
 			return false;
 		}
 		else if (arg == ARG_AVAILLANG || arg == ARG_AVAILLANG_SHORT)
@@ -135,9 +154,9 @@ bool ArgsParser::parseArgs()
 			if (!QFileInfo(m_file).exists())
 			{
 				if (m_file.left(1) == "-" || m_file.left(2) == "--")
-					std::cout << "Invalid argument: " << m_file.toStdString() << std::endl;
+					cout << QString("Invalid argument: ") << m_file << endl;
 				else
-					std::cout << "File " << m_file.toStdString() << " does not exist, aborting." << std::endl;
+					cout << QString("File ") << m_file << QString(" does not exist, aborting.") << endl;
 				return false;
 			}
 			return true;
@@ -171,6 +190,7 @@ int main(int argc, char ** argv)
 	app.installTranslator(&translator);
 
 	LiteManWindow * wnd = new LiteManWindow(cli.fileToOpen());
+	wnd->setLanguage(cli.localeCode());
 	wnd->show();
 
 	int r = app.exec();
@@ -210,6 +230,7 @@ void initCrashHandler()
 
 void defaultCrashHandler(int sig)
 {
+	QTextStream cout(stdout, QIODevice::WriteOnly);
 	static int crashRecursionCounter = 0;
 	crashRecursionCounter++;
 	signal(SIGALRM, SIG_DFL);
@@ -220,7 +241,7 @@ void defaultCrashHandler(int sig)
 All database opened will be rollbacked and closed.\n\n\
 Collect last steps that forced this\n\
 situlation and report it as a bug, please.").arg(sig));
-		std::cout << sigMsg.toStdString() << std::endl;
+		cout << sigMsg << endl;
 		QMessageBox::critical(0, "Sqliteman", sigMsg);
 		alarm(300);
 	}
@@ -236,6 +257,13 @@ The following pages contain an overview of the various classes, types and functi
 make the Sqliteman source code. To better understand Sqliteman, this document can provide an
 aid.
 
+Maybe you can think that the documentation is weak. OK, should be better but the code
+is clear in most cases.
+
 \note This Sw is a fork of Igor Khanin's original LiteMan. But now it's totally rewritten.
 You can find original copyright in the unmodified places.
+
+How to create fresh documentation? Download the source code from SVN. Go to the
+Sqliteman/devel-doc directory. Then run make. Doxygen is required, flawfinder and dot are
+optional.
  */
