@@ -14,9 +14,88 @@ for which a new license (GPL+exception) is in place.
 #include "ui_sqleditor.h"
 
 class QTextDocument;
-class SqlHighlighter;
 class QLabel;
-class Gluter;
+
+//! \brief Support tools for SqlEditor class
+namespace SqlEditorTools
+{
+
+	/*!
+	\brief Simple SQL syntax highlighter.
+	Taken and modified code from Scribus scripter and Qt docs.
+	\author Petr Vanek <petr@scribus.info>
+	*/
+	class SqlHighlighter : public QSyntaxHighlighter
+	{
+		Q_OBJECT
+
+	public:
+		SqlHighlighter(QTextDocument *parent = 0);
+
+	protected:
+		void highlightBlock(const QString &text);
+
+	private:
+		struct HighlightingRule
+		{
+			QRegExp pattern;
+			QTextCharFormat format;
+		};
+		QVector<HighlightingRule> highlightingRules;
+
+		QRegExp commentStartExpression;
+		QRegExp commentEndExpression;
+
+		QTextCharFormat keywordFormat;
+		QTextCharFormat singleLineCommentFormat;
+		QTextCharFormat multiLineCommentFormat;
+		QTextCharFormat quotationFormat;
+	};
+
+
+	/*! \brief A line numbers for the text widget
+	Taken from Azevedo Filipe's TextEditor.
+	http://www.monkeystudio.org/
+	*/
+	class Gluter : public QWidget
+	{
+		Q_OBJECT
+		Q_PROPERTY( int digitNumbers READ digitNumbers WRITE setDigitNumbers )
+		Q_PROPERTY( QColor textColor READ textColor WRITE setTextColor )
+		Q_PROPERTY( QColor backgroundColor READ backgroundColor WRITE setBackgroundColor )
+		//
+	public:
+		Gluter( QTextEdit* );
+		//
+		void setDigitNumbers( int );
+		int digitNumbers() const;
+		//
+		void setTextColor( const QColor& );
+		const QColor& textColor() const;
+		//
+		void setBackgroundColor( const QColor& );
+		const QColor& backgroundColor() const;
+		//
+	protected:
+		virtual void paintEvent( QPaintEvent* );
+		//
+	private:
+		QTextEdit* mEdit;
+		int mDigitNumbers;
+		QColor mTextColor;
+		QColor mBackgroundColor;
+		//
+	signals:	
+		void digitNumbersChanged( int );
+		void textColorChanged( const QColor& );
+		void backgroundColorChanged( const QColor& );
+		//
+	public slots:
+		void setDefaultProperties();
+	};
+
+};
+
 
 /*!
 \brief Execute Query dialog. Simple SQL editor.
@@ -49,8 +128,8 @@ class SqlEditor : public QMainWindow
 
 	private:
 		Ui::SqlEditor ui;
-		SqlHighlighter *highlighter;
-		Gluter *mGluter;
+		SqlEditorTools::SqlHighlighter *highlighter;
+		SqlEditorTools::Gluter *mGluter;
 
 		QString m_fileName;
 
@@ -80,79 +159,4 @@ class SqlEditor : public QMainWindow
 		void documentChanged(bool state);
 };
 
-
-/*!
-\brief Simple SQL syntax highlighter.
-Taken and modified code from Scribus scripter and Qt docs.
-\author Petr Vanek <petr@scribus.info>
-*/
-class SqlHighlighter : public QSyntaxHighlighter
-{
-    Q_OBJECT
-
-public:
-	SqlHighlighter(QTextDocument *parent = 0);
-
-protected:
-	void highlightBlock(const QString &text);
-
-private:
-	struct HighlightingRule
-	{
-		QRegExp pattern;
-		QTextCharFormat format;
-	};
-	QVector<HighlightingRule> highlightingRules;
-
-	QRegExp commentStartExpression;
-	QRegExp commentEndExpression;
-
-	QTextCharFormat keywordFormat;
-	QTextCharFormat singleLineCommentFormat;
-	QTextCharFormat multiLineCommentFormat;
-	QTextCharFormat quotationFormat;
-};
-
-
-/*! \brief A line numbers for the text widget
-Taken from Azevedo Filipe's TextEditor.
-http://www.monkeystudio.org/
-*/
-class Gluter : public QWidget
-{
-	Q_OBJECT
-	Q_PROPERTY( int digitNumbers READ digitNumbers WRITE setDigitNumbers )
-	Q_PROPERTY( QColor textColor READ textColor WRITE setTextColor )
-	Q_PROPERTY( QColor backgroundColor READ backgroundColor WRITE setBackgroundColor )
-	//
-public:
-	Gluter( QTextEdit* );
-	//
-	void setDigitNumbers( int );
-	int digitNumbers() const;
-	//
-	void setTextColor( const QColor& );
-	const QColor& textColor() const;
-	//
-	void setBackgroundColor( const QColor& );
-	const QColor& backgroundColor() const;
-	//
-protected:
-	virtual void paintEvent( QPaintEvent* );
-	//
-private:
-	QTextEdit* mEdit;
-	int mDigitNumbers;
-	QColor mTextColor;
-	QColor mBackgroundColor;
-	//
-signals:	
-	void digitNumbersChanged( int );
-	void textColorChanged( const QColor& );
-	void backgroundColorChanged( const QColor& );
-	//
-public slots:
-	void setDefaultProperties();
-};
-
 #endif
