@@ -7,7 +7,7 @@ for which a new license (GPL+exception) is in place.
 #include "sqlparser.h"
 
 
-SqlParser::SqlParser(QString text)
+SqlEditorTools::SqlParser::SqlParser(QString text)
 	: QObject(),
 	m_update(false)
 {
@@ -15,7 +15,7 @@ SqlParser::SqlParser(QString text)
 	m_string = text;
 }
 
-QString SqlParser::getStatement(int cursorPosition)
+QString SqlEditorTools::SqlParser::getStatement(int cursorPosition)
 {
 	int currPosition = -1;
 	int start = 0;
@@ -74,7 +74,11 @@ QString SqlParser::getStatement(int cursorPosition)
 						 || currLine.mid(column, 6).toUpper() == "ATTACH"
 						 || currLine.mid(column, 6).toUpper() == "DETACH"
 						 || currLine.mid(column, 7).toUpper() == "ANALYZE"
-						 || currLine.mid(column, 7).toUpper() == "REINDEX")
+						 || currLine.mid(column, 7).toUpper() == "REINDEX"
+						 || currLine.mid(column, 6).toUpper() == "INSERT"
+						 || currLine.mid(column, 6).toUpper() == "UPDATE"
+						 || currLine.mid(column, 6).toUpper() == "DELETE"
+						 || currLine.mid(column, 7).toUpper() == "REPLACE")
 			   )
 			{
 				started = true;
@@ -106,11 +110,12 @@ QString SqlParser::getStatement(int cursorPosition)
 	return QString("SQL statement not found. Pos: %1. Start: %2. End: %3.").arg(cursorPosition).arg(start).arg(end);
 }
 
-bool SqlParser::updateTree(const QString & sql)
+bool SqlEditorTools::SqlParser::updateTree(const QString & sql)
 {
 	if (sql.isNull())
 		return false;
-	if (sql.trimmed().left(4).toUpper() == "DROP" || sql.trimmed().left(6).toUpper() == "CREATE")
+	QString tmp(sql.trimmed().toUpper());
+	if (tmp.left(4) == "DROP" || tmp.left(6) == "CREATE" || tmp.left(5) == "ALTER")
 		return true;
 	return false;
 }
