@@ -16,7 +16,7 @@ for which a new license (GPL+exception) is in place.
 TableEditorDialog::TableEditorDialog(QWidget * parent)//, Mode mode, const QString & tableName): QDialog(parent)
 {
 	ui.setupUi(this);
-	highlighter = new SqlHighlighter(ui.textEdit->document());
+	new SqlEditorTools::SqlHighlighter(ui.textEdit->document());
 	ui.databaseCombo->addItems(Database::getDatabases().keys());
 
 	connect(ui.nameEdit, SIGNAL(textChanged(const QString&)),
