@@ -547,7 +547,7 @@
 <context>
     <name>DataViewer</name>
     <message>
-        <location filename="../dataviewer.cpp" line="148"/>
+        <location filename="../dataviewer.cpp" line="152"/>
         <source>Sqliteman</source>
         <translation>Sqliteman</translation>
     </message>
@@ -592,7 +592,7 @@
         <translation>Eksport danych</translation>
     </message>
     <message>
-        <location filename="../dataviewer.cpp" line="151"/>
+        <location filename="../dataviewer.cpp" line="155"/>
         <source>There is a pending transaction in progress. That cannot be commited now.
 Error: %1
 Perform rollback?</source>
@@ -770,32 +770,32 @@ Anuluj = wróć z powrotem do tabeli</translation>
         <translation>&amp;O...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="155"/>
+        <location filename="../litemanwindow.cpp" line="158"/>
         <source>&amp;Help Content...</source>
         <translation>Zawartość &amp;pomocy...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="156"/>
+        <location filename="../litemanwindow.cpp" line="159"/>
         <source>F1</source>
         <translation>F1</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="159"/>
+        <location filename="../litemanwindow.cpp" line="162"/>
         <source>&amp;SQL Editor</source>
         <translation>Edytor &amp;SQL</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="160"/>
+        <location filename="../litemanwindow.cpp" line="163"/>
         <source>Ctrl+E</source>
         <translation>Ctrl+E</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="169"/>
+        <location filename="../litemanwindow.cpp" line="172"/>
         <source>&amp;Build Query...</source>
         <translation>U&amp;twórz zapytanie...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="170"/>
+        <location filename="../litemanwindow.cpp" line="173"/>
         <source>Ctrl+R</source>
         <translation>Ctrl+R</translation>
     </message>
@@ -805,177 +805,177 @@ Anuluj = wróć z powrotem do tabeli</translation>
         <translation type="obsolete">&amp;Eksport SQL...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="179"/>
+        <location filename="../litemanwindow.cpp" line="182"/>
         <source>&amp;Create Table...</source>
         <translation>U&amp;twórz tabelę...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="180"/>
+        <location filename="../litemanwindow.cpp" line="183"/>
         <source>Ctrl+T</source>
         <translation>Ctrl+T</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="183"/>
+        <location filename="../litemanwindow.cpp" line="186"/>
         <source>&amp;Drop Table</source>
         <translation>&amp;Usuń tabelę</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="186"/>
+        <location filename="../litemanwindow.cpp" line="189"/>
         <source>&amp;Alter Table...</source>
         <translation>&amp;Edytuj tabelę...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="187"/>
+        <location filename="../litemanwindow.cpp" line="190"/>
         <source>Ctrl+A</source>
         <translation>Ctrl+A</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="190"/>
+        <location filename="../litemanwindow.cpp" line="193"/>
         <source>Create &amp;View...</source>
         <translation>Utwórz &amp;widok...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="191"/>
+        <location filename="../litemanwindow.cpp" line="194"/>
         <source>Ctrl+G</source>
         <translation>Ctrl+G</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="194"/>
+        <location filename="../litemanwindow.cpp" line="197"/>
         <source>&amp;Drop View</source>
         <translation>&amp;Usuń widok</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="197"/>
+        <location filename="../litemanwindow.cpp" line="200"/>
         <source>&amp;Alter View...</source>
         <translation>&amp;Edytuj widok...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="200"/>
+        <location filename="../litemanwindow.cpp" line="203"/>
         <source>&amp;Create Index...</source>
         <translation>U&amp;twórz indeks...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="203"/>
+        <location filename="../litemanwindow.cpp" line="206"/>
         <source>&amp;Drop Index</source>
         <translation>&amp;Usuń indeks</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="206"/>
+        <location filename="../litemanwindow.cpp" line="209"/>
         <source>D&amp;escribe Table</source>
         <translation>&amp;Opisz tabelę</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="209"/>
+        <location filename="../litemanwindow.cpp" line="212"/>
         <source>&amp;Create Trigger...</source>
         <translation>U&amp;twórz trigger...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="212"/>
+        <location filename="../litemanwindow.cpp" line="215"/>
         <source>&amp;Alter Trigger...</source>
         <translation>&amp;Edytuj trigger...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="215"/>
+        <location filename="../litemanwindow.cpp" line="218"/>
         <source>&amp;Drop Trigger</source>
         <translation>&amp;Usuń trigger</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="218"/>
+        <location filename="../litemanwindow.cpp" line="221"/>
         <source>D&amp;escribe Trigger</source>
         <translation>&amp;Opisz trigger</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="221"/>
+        <location filename="../litemanwindow.cpp" line="224"/>
         <source>D&amp;escribe View</source>
         <translation>&amp;Opisz widok</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="224"/>
+        <location filename="../litemanwindow.cpp" line="227"/>
         <source>D&amp;escribe Index</source>
         <translation>&amp;Opisz indeks</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="227"/>
+        <location filename="../litemanwindow.cpp" line="230"/>
         <source>&amp;Reindex</source>
         <translation>&amp;Reindeksuj</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="230"/>
+        <location filename="../litemanwindow.cpp" line="233"/>
         <source>&amp;Analyze Statistics...</source>
         <translation>&amp;Statystyki...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="233"/>
+        <location filename="../litemanwindow.cpp" line="236"/>
         <source>&amp;Vacuum...</source>
         <translation>&amp;Kompaktuj...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="236"/>
+        <location filename="../litemanwindow.cpp" line="239"/>
         <source>A&amp;ttach Database...</source>
         <translation>&amp;Dołącz bazę danych...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="239"/>
+        <location filename="../litemanwindow.cpp" line="242"/>
         <source>&amp;Detach Database</source>
         <translation>&amp;Odłącz bazę danych</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="245"/>
+        <location filename="../litemanwindow.cpp" line="248"/>
         <source>&amp;Constraint Triggers...</source>
         <translation>&amp;Constraint Triggers...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="251"/>
+        <location filename="../litemanwindow.cpp" line="254"/>
         <source>&amp;File</source>
         <translation>&amp;Plik</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="260"/>
+        <location filename="../litemanwindow.cpp" line="263"/>
         <source>&amp;Context</source>
         <translation>&amp;Kontekst</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="263"/>
+        <location filename="../litemanwindow.cpp" line="266"/>
         <source>&amp;Database</source>
         <translation>Baza &amp;Danych</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="274"/>
+        <location filename="../litemanwindow.cpp" line="277"/>
         <source>&amp;System</source>
         <translation>&amp;System</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="280"/>
+        <location filename="../litemanwindow.cpp" line="283"/>
         <source>&amp;Help</source>
         <translation>&amp;Pomoc</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="372"/>
+        <location filename="../litemanwindow.cpp" line="376"/>
         <source>New Database</source>
         <translation>Nowa baza danych</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="844"/>
+        <location filename="../litemanwindow.cpp" line="853"/>
         <source>SQLite database (*)</source>
         <translation>Baza danych SQLite (*)</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="392"/>
+        <location filename="../litemanwindow.cpp" line="396"/>
         <source>Open Database</source>
         <translation>Otwórz bazę danych</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="862"/>
+        <location filename="../litemanwindow.cpp" line="871"/>
         <source>Unable to open or create file %1. It is probably not a database</source>
         <translation>Nie można otworzyć lub utworzyć pliku %1. Prawdopodobnie to nie jest baza danych</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="444"/>
+        <location filename="../litemanwindow.cpp" line="448"/>
         <source>About</source>
         <translation>O</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="447"/>
+        <location filename="../litemanwindow.cpp" line="451"/>
         <source>Sqliteman - SQLite databases made easy
 
 Version %1
@@ -988,17 +988,17 @@ Wersja %1
 tłumaczenie: Kamil Leś</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="485"/>
+        <location filename="../litemanwindow.cpp" line="494"/>
         <source>No SQL statement</source>
         <translation>Brak wyrażenia SQL</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="485"/>
+        <location filename="../litemanwindow.cpp" line="494"/>
         <source>You are trying to run an undefined SQL query. Hint: select your query in the editor</source>
         <translation>Próbujesz wykonać niezdefiniowane zapytanie. Spróbuj zaznaczyć zapytanie w edytorze</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="508"/>
+        <location filename="../litemanwindow.cpp" line="517"/>
         <source>Query Error: %1
 
 %2</source>
@@ -1007,7 +1007,7 @@ tłumaczenie: Kamil Leś</translation>
 %2</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="511"/>
+        <location filename="../litemanwindow.cpp" line="520"/>
         <source>Query OK
 Row(s) returned: %1
 
@@ -1023,49 +1023,49 @@ zwrócono: %1 rekord(y/ów)
         <translation type="obsolete">Eksport SQL</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="529"/>
+        <location filename="../litemanwindow.cpp" line="538"/>
         <source>SQL File (*.sql)</source>
         <translation>Plik SQL (*.sql)</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="598"/>
+        <location filename="../litemanwindow.cpp" line="607"/>
         <source>Are you sure that you wish to drop the table &quot;%1&quot;?</source>
         <translation>Jesteś pewien, że chcesz usunąć tabelę &quot;%1&quot;?</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="635"/>
+        <location filename="../litemanwindow.cpp" line="644"/>
         <source>Are you sure that you wish to drop the view &quot;%1&quot;?</source>
         <translation>Jesteś pewien, że chcesz usunąć widok &quot;%1&quot;?</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="664"/>
+        <location filename="../litemanwindow.cpp" line="673"/>
         <source>Are you sure that you wish to drop the index &quot;%1&quot;?</source>
         <translation>Jesteś pewien, że chcesz usunąć indeks &quot;%1&quot;?</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="817"/>
+        <location filename="../litemanwindow.cpp" line="826"/>
         <source>Query Error: %1</source>
         <translation>Błąd w zapytaniu: %1</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="819"/>
+        <location filename="../litemanwindow.cpp" line="828"/>
         <source>Query OK
 Row(s) returned: %1</source>
         <translation>Zapytanie w porządku
 zwrócono: %1 rekord(y/ów)</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="849"/>
+        <location filename="../litemanwindow.cpp" line="858"/>
         <source>Attach Database</source>
         <translation>Dołącz bazę danych</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="850"/>
+        <location filename="../litemanwindow.cpp" line="859"/>
         <source>Enter a Schema Alias:</source>
         <translation>Wprowadź alias:</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="913"/>
+        <location filename="../litemanwindow.cpp" line="922"/>
         <source>Are you sure that you wish to drop the trigger &quot;%1&quot;?</source>
         <translation>Jesteś pewien, że chcesz usunąć trigger &quot;%1&quot;?</translation>
     </message>
@@ -1075,80 +1075,85 @@ zwrócono: %1 rekord(y/ów)</translation>
         <translation>&amp;Preferencje...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="173"/>
+        <location filename="../litemanwindow.cpp" line="176"/>
         <source>&amp;Export Schema...</source>
         <translation>&amp;Eksport schematu...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="176"/>
+        <location filename="../litemanwindow.cpp" line="179"/>
         <source>&amp;Dump Database...</source>
         <translation>&amp;Zrzut bazy danych...</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="519"/>
+        <location filename="../litemanwindow.cpp" line="528"/>
         <source>Export Schema</source>
         <translation>Eksport schematu</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="529"/>
+        <location filename="../litemanwindow.cpp" line="538"/>
         <source>Export Database</source>
         <translation>Eksport bazy danych</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="543"/>
+        <location filename="../litemanwindow.cpp" line="552"/>
         <source>The process failed to start. Either the invoked program is missing, or you may have insufficient permissions to invoke the program.</source>
         <translation>Błąd podczas uruchamiania. Albo nie ma takiego programu albo brak wystarczających uprawnień do jego uruchomienia.</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="546"/>
+        <location filename="../litemanwindow.cpp" line="555"/>
         <source>The process crashed some time after starting successfully.</source>
         <translation>Proces przestał funkcjonować jakiś czas po uruchomieniu.</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="549"/>
+        <location filename="../litemanwindow.cpp" line="558"/>
         <source>An error occurred when attempting to write to the process. For example, the process may not be running, or it may have closed its input channel.</source>
         <translation>Pojawił się błąd podczas zapisu.Prawdopodobnie proces został zatrzymany albo został zamknięty kanał wejściowy.</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="552"/>
+        <location filename="../litemanwindow.cpp" line="561"/>
         <source>An error occurred when attempting to read from the process. For example, the process may not be running.</source>
         <translation>Pojawił się błąd podczas odczytu. Prawdopodobnie proces został zatrzymany.</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="555"/>
+        <location filename="../litemanwindow.cpp" line="564"/>
         <source>An unknown error occurred.</source>
         <translation>Pojawił się nieznany błąd.</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="557"/>
+        <location filename="../litemanwindow.cpp" line="566"/>
         <source>Error creating the dump. Reason: %1</source>
         <translation>Pojawił się błąd podczas robienia zrzutu. Powód: %1</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="560"/>
+        <location filename="../litemanwindow.cpp" line="569"/>
         <source>Dump written into: %1</source>
         <translation>Zrzut zapisany do: %1</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="164"/>
+        <location filename="../litemanwindow.cpp" line="167"/>
         <source>Object &amp;Browser</source>
         <translation>Eksplorator &amp;bazy danych</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="165"/>
+        <location filename="../litemanwindow.cpp" line="168"/>
         <source>Ctrl+B</source>
         <translation>Ctrl+B</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="242"/>
+        <location filename="../litemanwindow.cpp" line="245"/>
         <source>&amp;Refresh Object Tree</source>
         <translation>Odśwież zawa&amp;rtość</translation>
     </message>
     <message>
-        <location filename="../litemanwindow.cpp" line="504"/>
+        <location filename="../litemanwindow.cpp" line="513"/>
         <source>Duration: %1 seconds</source>
         <translation>Czas: %1 sekund</translation>
     </message>
+    <message>
+        <location filename="../litemanwindow.cpp" line="155"/>
+        <source>About &amp;Qt...</source>
+        <translation>O &amp;Qt...</translation>
+    </message>
 </context>
 <context>
     <name>PreferencesDialog</name>
